internal: Internal functions for ordered factor regression functions

internalR Documentation

Internal functions for ordered factor regression functions

Description

Internal functions for ordered factor regression functions.

Details

These functions are not intended to be called by users directly.

Abeta

Function A(\bold{\beta}) in Rufibach (2010) that collects the indices of the inequalities violated by \bold{\beta}.

constraintMats

Function that computes the matrices \bold{B} (collects the basis vectors given in Theorem 3.1 of Duembgen et al. (2007)) and \bold{V} (collects the vectors \bold{v}_i that make up the cone K in Section 3.1 of Duembgen et al. (2007)).

coxDeriv

Computes gradient of (pseudo-)log-likelihood function in Cox-regression.

coxLoglik

Computes value of (pseudo-)log-likelihood function in Cox-regression.

coxSubspace

Computes maximizer on subspace, denoted by \widetilde{\psi}(A) in Table 1 of Duembgen et al. (2007).

dummy

Generate a matrix of dummy variables corresponding to the levels of the inputed factor. The dummy variable corresponding to the lowest level of the factor is omitted.

expandBeta

After computation of \bold{\beta} on subspace “blow up” this vector again to original dimension.

indexDummy

Compute column numbers of the dummy variables of the ordered factor(s).

lmLSE

Compute value of least squares criterion and least squares estimate.

lmSS

Compute value of least squares criterion and its gradient.

logRegDeriv

Gradient of log-likelihood function in logistic regression.

logRegLoglik

Compute value of log-likelihood function in logistic regression.

logRegSubspace

Computes maximizer on subspace, denoted by \widetilde{\psi}(A) in Table 1 of Duembgen et al. (2007).

LSEsubspace

Computes maximizer on subspace, denoted by \widetilde{\psi}(A) in Table 1 of Duembgen et al. (2007).

maxStep

Compute maximal permissible steplength, denoted by t in Table 1 in Duembgen et al. (2007).

phi_jl

Function \phi in Rufibach (2010) that maps the original indices (i, j) to the inequality index i.

setminus

Remove elements in vector B from vector A.

shrinkBeta

Collapse \bold{\beta} according to the active constraints specified by the set A.

Author(s)

Kaspar Rufibach (maintainer)
kaspar.rufibach@gmail.com
http://www.kasparrufibach.ch

References

Duembgen, L., Huesler, A. and Rufibach, K. (2010). Active set and EM algorithms for log-concave densities based on complete and censored data. Technical report 61, IMSV, Univ. of Bern, available at https://arxiv.org/abs/0707.4643.

Rufibach, K. (2010). An Active Set Algorithm to Estimate Parameters in Generalized Linear Models with Ordered Predictors. Comput. Statist. Data Anal., 54, 1442-1456.

See Also

All these functions are used by the ordered factor computation functions ordFacReg and ordFacRegCox.


OrdFacReg documentation built on April 27, 2026, 1:07 a.m.